Package 'lulab.utils'

Title: Supporting Functions Maintained by Zhen Lu
Description: Miscellaneous functions commonly used by LuLab. This package aims to help more researchers on epidemiology to perform data management and visualization more efficiently.
Authors: Zhen Lu [aut, cre]
Maintainer: Zhen Lu <[email protected]>
License: MIT + file LICENSE
Version: 1.0.2
Built: 2026-06-08 13:01:10 UTC
Source: https://github.com/Leslie-Lu/lulab.utils

Help Index


check_cha

Description

Check for missing values for character columns

Usage

check_cha(col, df, verbose = TRUE)

Arguments

col

a character variable name

df

a data.frame

verbose

logical, controlling the output

Details

This function is used to check the distribution of character variables in the data frame.

Value

a distribution table of the character variable in the data frame

Author(s)

Zhen Lu

Examples

data("melanoma", package = "boot")
melanoma2 <- melanoma
check_cha('status', melanoma2)
# or
mapply(check_cha,'status', MoreArgs= list(melanoma2))

check_wget

Description

Check if wget is installed

Usage

check_wget()

Details

This function is used to check if wget is installed on the system.

Value

a logical value indicating whether wget is installed

Author(s)

Zhen Lu

Examples

check_wget()

extract_logistic_model

Description

Extract results from a fitted model.

Usage

extract_logistic_model(
  model,
  markers_name,
  n_independent_metabolites,
  digits,
  effective_size,
  case_size,
  control_size,
  outcome_name
)

Arguments

model

The fitted logistic model object.

markers_name

A character vector of marker names.

n_independent_metabolites

The number of independent metabolites.

digits

The number of decimal places to round to.

effective_size

A numeric vector containing effective sample sizes.

case_size

The number of cases.

control_size

The number of controls.

outcome_name

The name of the outcome variable.

Details

This function extracts relevant results from a fitted logistic model and formats them for reporting.

Value

A named vector containing the extracted results.


round2

Description

Round a number to a specified number of decimal places.

Usage

round2(x, digits = 0)

Arguments

x

The numeric input to be rounded.

digits

The number of decimal places to round to, Default: digits

Details

This function rounds the input number to the specified number of decimal places.

Value

The rounded numeric value.


Make a Table 1 summary

Description

Create a stratified Table 1, save it as an Excel workbook, and return the table as a data frame.

Usage

Table1(df, ycol, xcol, xlabels = NULL, result_dir, verbose = TRUE)

Arguments

df

A data frame.

ycol

A single character string naming the grouping variable.

xcol

A character vector naming variables to summarize.

xlabels

Optional labels for the groups. Defaults to the observed levels of ycol.

result_dir

Directory where Table1.xlsx will be saved.

verbose

Logical; if TRUE, print the output path.

Value

A data frame containing the rendered Table 1.

Author(s)

Zhen Lu

Examples

data("melanoma", package = "boot")
melanoma2 <- melanoma
melanoma2$status <- factor(
  melanoma2$status,
  levels = c(2, 1, 3),
  labels = c("Alive", "Melanoma death", "Non-melanoma death")
)
Table1(
  df = melanoma2,
  ycol = "status",
  xcol = c("time", "age", "sex"),
  result_dir = tempdir()
)

test_mirror

Description

Test speed of CRAN mirror

Usage

test_mirror(region, verbose = TRUE)

Arguments

region

a character string, the region of the CRAN mirror, e.g. 'China'

verbose

logical, controlling the output

Details

This function is used to test the speed of CRAN mirror.

Value

a data.frame with the name, URL, and download time of the fastest CRAN mirror

Author(s)

Zhen Lu

Examples

test_mirror('China')

use_wget

Description

Use wget to download files

Usage

use_wget(use = TRUE)

Arguments

use

a logical value, controlling the download method

Details

This function is used to set the download method.

Value

a logical value indicating whether wget is used

Author(s)

Zhen Lu

Examples

use_wget(use = TRUE)
getOption("download.file.method")
getOption("download.file.extra") 
test_url <- "https://eternallybored.org/misc/wget/1.21.4/64/wget.exe"
test_destfile <- tempfile()
download.file(test_url, destfile = test_destfile)